# twitter_bot_tracking

This library is to ease the operation of creating twitter bots and tracking it's ativities
 
In order to install, open the command prompt and type:
```
pip install twitter-bot-tracking
```

In order to work with s3 mode you have to use aws_cli library for the configurations, [see here](https://pypi.org/project/awscli/) for more details
